tlslite.utils.openssl_aes.OpenSSL_AES

Package tlslite :: Package utils :: Module openssl_aes :: Class OpenSSL_AES |
[hide private]
[frames] | no frames]

# Class OpenSSL_AES

source code

    aes.AES --+
              |
             OpenSSL_AES

Instance Methods | [hide private]
__init__(self, key, mode, IV) | source code
_createContext(self, encrypt) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code

Method Details | [hide private]

### __init__(self, key, mode, IV) (Constructor) | source code
Overrides: aes.AES.__init__

### decrypt(self, ciphertext) | source code
Overrides: aes.AES.decrypt

### encrypt(self, plaintext) | source code
Overrides: aes.AES.encrypt